@@ -49,30 +49,17 @@
 
 package com.openexchange.documentconverter.client.impl;
 
-import java.awt.image.BufferedImage;
-import java.io.ByteArrayInputStream;
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.HashMap;
-import javax.imageio.ImageIO;
-import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
-import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.documentconverter.AsyncExecutor;
 import com.openexchange.documentconverter.IDocumentConverter;
-import com.openexchange.documentconverter.IImageTransformer;
 import com.openexchange.documentconverter.ILogProvider;
-import com.openexchange.documentconverter.ImageServerTransformations;
 import com.openexchange.documentconverter.LogData;
 import com.openexchange.documentconverter.LogType;
 import com.openexchange.documentconverter.ManagerBasics;
 import com.openexchange.documentconverter.ServerType;
-import com.openexchange.exception.OXException;
-import com.openexchange.imagetransformation.ImageServerTransformationService;
-import com.openexchange.imagetransformation.ImageTransformations;
-import com.openexchange.imagetransformation.TransformedImage;
 import com.openexchange.server.ServiceLookup;
 
 
@@ -82,7 +69,7 @@ import com.openexchange.server.ServiceLookup;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  * @since v7.8.0
  */
-public class ClientManager extends ManagerBasics implements IDocumentConverter, IImageTransformer, ImageServerTransformationService {
+public class ClientManager extends ManagerBasics implements IDocumentConverter {
 
 
     /**
@@ -100,19 +87,12 @@ public class ClientManager extends ManagerBasics implements IDocumentConverter,
 
         m_asyncExecutor = new AsyncExecutor(this, this, ASYNC_CONVERTER_THREADCOUNT);
 
-     // create remoteValidators for each configured remote server type
+        // create remoteValidators for each configured remote server type
         if ((null != m_clientConfig.REMOTEURL_DOCUMENTCONVERTER) && (m_clientConfig.REMOTEURL_DOCUMENTCONVERTER.toString().length() > 0)) {
             m_remoteDocumentConverterValidator = new RemoteValidator(ServerType.DOCUMENTCONVERTER, m_clientConfig.REMOTEURL_DOCUMENTCONVERTER);
         } else if (isLogError()) {
             logError("Documentconverter remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set!");
         }
-
-        // create remoteValidators for each configured remote server type
-        if ((null != m_clientConfig.REMOTEURL_IMAGESERVER) && (m_clientConfig.REMOTEURL_IMAGESERVER.toString().length() > 0)) {
-            m_remoteImageServerValidator = new RemoteValidator(ServerType.IMAGESERVER, m_clientConfig.REMOTEURL_IMAGESERVER);
-        } else if (isLogError()) {
-            logError("Documentconverter remoteImageServerUrl property is empty or not set at all. Client is not able to perform image transformations until a valid Url is set!");
-        }
     }
 
     /**
@@ -133,9 +113,7 @@ public class ClientManager extends ManagerBasics implements IDocumentConverter,
      */
     @Override
     public InputStream convert(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        final ServerType serverType = (!StringUtils.isEmpty(jobType) && jobType.equals("imagetransformation")) ? ServerType.IMAGESERVER : ServerType.DOCUMENTCONVERTER;
-
-        return (new ManagedClientHashJob(this, serverType)).process(jobType, jobProperties, resultProperties);
+        return (new ManagedClientHashJob(this, ServerType.DOCUMENTCONVERTER)).process(jobType, jobProperties, resultProperties);
     }
 
     /* (non-Javadoc)
@@ -162,100 +140,6 @@ public class ClientManager extends ManagerBasics implements IDocumentConverter,
         (new ManagedClientHashJob(this, ServerType.DOCUMENTCONVERTER)).endPageConversion(jobIdStr, jobProperties, resultProperties);
     }
 
-    // - IImageTransformer -----------------------------------------------------
-
-    @Override
-    public TransformedImage transformImage(InputStream imageInputStm, String formatName, Object userData) {
-        TransformedImage ret = null;
-
-        if ((null != imageInputStm) && !StringUtils.isEmpty(formatName) && (null != userData) && (userData instanceof ImageServerTransformations)) {
-            final ImageTransformations imageTransformations = m_services.getOptionalService(ImageTransformations.class);
-
-            if (null != imageTransformations) {
-                final ImageServerTransformations imageServerTransformations = (ImageServerTransformations) userData;
-
-                // TODO (KA): impl.
-            }
-        }
-
-        return ret;
-    }
-
-    // - ImageTransformationService --------------------------------------
-
-    @Override
-    public ImageTransformations transfom(BufferedImage sourceImage) throws IOException {
-        return transfom(sourceImage, null);
-    }
-
-    @Override
-    public ImageTransformations transfom(BufferedImage sourceImage, Object source) throws IOException {
-        ImageTransformations ret = null;
-
-        if ((null != sourceImage) && (sourceImage.getWidth() > 0) && (sourceImage.getHeight() > 0)) {
-            final ByteArrayOutputStream byteArrayOutputStm = new ByteArrayOutputStream();
-
-            ImageIO.write(sourceImage, "png", byteArrayOutputStm);
-
-            final byte[] imageData = byteArrayOutputStm.toByteArray();
-
-            if ((null != imageData) && (imageData.length > 0)) {
-                try (final InputStream imageStm = new ByteArrayInputStream(imageData)) {
-                    ret = transfom(imageStm, source);
-                }
-            }
-        }
-
-        return ret;
-    }
-
-    @Override
-    public ImageTransformations transfom(InputStream imageStm) throws IOException {
-        return transfom(imageStm, null);
-    }
-
-    @Override
-    public ImageTransformations transfom(InputStream imageStm, Object source) throws IOException {
-        return ((null != imageStm) ? new ImageServerTransformations(this, imageStm, source) : null);
-    }
-
-    @Override
-    public ImageTransformations transfom(IFileHolder imageFile, Object source) throws IOException {
-        ImageTransformations ret = null;
-
-        if ((null != imageFile) && (imageFile.getLength() > 0)) {
-            try (final InputStream inputStm = imageFile.getStream()) {
-
-                if (null != inputStm) {
-                    ret = transfom(inputStm, source);
-                }
-            } catch (OXException e) {
-                logExcp(e);
-            }
-        }
-
-        return ret;
-    }
-
-    @Override
-    public ImageTransformations transfom(byte[] imageData) throws IOException {
-        return transfom(imageData, null);
-    }
-
-    @Override
-    public ImageTransformations transfom(byte[] imageData, Object source) throws IOException {
-
-        ImageTransformations ret = null;
-
-        if ((null != imageData) && (imageData.length > 0)) {
-            try (final InputStream inputStm = new ByteArrayInputStream(imageData)) {
-                ret = transfom(inputStm, source);
-            }
-        }
-
-        return ret;
-    }
-
     // - ILogProvider ----------------------------------------------------------
 
     /**
@@ -354,8 +238,7 @@ public class ClientManager extends ManagerBasics implements IDocumentConverter,
      * @return
      */
     protected RemoteValidator getRemoteValidator(ServerType serverType) {
-        return ((ServerType.DOCUMENTCONVERTER == serverType) ? m_remoteDocumentConverterValidator :
-                ((ServerType.IMAGESERVER == serverType) ? m_remoteImageServerValidator : null));
+        return ((ServerType.DOCUMENTCONVERTER == serverType) ? m_remoteDocumentConverterValidator : null);
     }
 
     // - Config ----------------------------------------------------------------
@@ -524,7 +407,5 @@ public class ClientManager extends ManagerBasics implements IDocumentConverter,
 
     private RemoteValidator m_remoteDocumentConverterValidator = null;
 
-    private RemoteValidator m_remoteImageServerValidator = null;
-
     private AsyncExecutor m_asyncExecutor = null;
 }
