@@ -58,7 +58,7 @@ import com.openexchange.documentconverter.LogData;
 import com.openexchange.documentconverter.ManagerBasics;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
-import com.openexchange.documentconverter.ServerType;;
+import com.openexchange.documentconverter.ServerType;
 
 /**
  * {@link ManagedClientHashJob}
@@ -306,7 +306,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * @param deleteInputFileProperty
      * @return
      */
-    HashMap<String, Object> createFileBasedJobProperties(HashMap<String, Object> jobProperties, boolean[] deleteInputFileProperty) {
+    static HashMap<String, Object> createFileBasedJobProperties(HashMap<String, Object> jobProperties, boolean[] deleteInputFileProperty) {
         final File jobInputFile = ManagerBasics.getJobInputFile(jobProperties, deleteInputFileProperty);
         HashMap<String, Object> fileBasedJobProperties = null;
 
