@@ -63,16 +63,17 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLEncoder;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.commons.codec.binary.Base64;
+import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONTokener;
-import com.openexchange.documentconverter.ImageServerTransformations;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.LogData;
@@ -109,11 +110,6 @@ class ManagedClientJob {
                     break;
                 }
 
-                case IMAGESERVER: {
-                    m_remoteUrl = ClientManager.getClientConfig().REMOTEURL_IMAGESERVER;
-                    break;
-                }
-
                 case CACHESERVER:
                 default: {
                     break;
@@ -138,7 +134,7 @@ class ManagedClientJob {
                 doRemoteCall(jobProperties, resultProperties);
 
                 ret = resultProperties.containsKey(Properties.PROP_RESULT_ERROR_CODE) &&
-                        (JobError.NONE == JobError.fromErrorCode(((Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)).intValue()));
+                    (JobError.NONE == JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
             }
         }
 
@@ -154,7 +150,9 @@ class ManagedClientJob {
         final Boolean asyncObject = (Boolean) jobProperties.get(Properties.PROP_ASYNC);
 
         if ((null != asyncObject) && asyncObject.booleanValue()) {
-            if (checkJobInputFileSize(jobProperties, resultProperties)) {
+            if (checkJobInputFileSize(jobProperties, resultProperties) &&
+                checkSupportedJobInputType(jobProperties, resultProperties)) {
+
                 m_clientManager.triggerAsyncConvert(jobType, jobProperties, resultProperties);
             }
         } else if (checkJobPreconditions(jobProperties, resultProperties, 1)) {
@@ -244,24 +242,17 @@ class ManagedClientJob {
      * @return
      */
     static protected byte[] getInputBuffer(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
-        @SuppressWarnings("resource")
-        InputStream inputStm = null;
         byte[] ret = null;
 
-        try {
-            if (jobProperties.containsKey(Properties.PROP_INPUT_FILE)) {
-                inputStm = new FileInputStream((File) jobProperties.get(com.openexchange.documentconverter.Properties.PROP_INPUT_FILE));
-            } else if (jobProperties.containsKey(Properties.PROP_INPUT_STREAM)) {
-                inputStm = (InputStream) jobProperties.get(Properties.PROP_INPUT_STREAM);
-            }
+        try (final InputStream inputStm = (jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
+            new FileInputStream((File) jobProperties.get(com.openexchange.documentconverter.Properties.PROP_INPUT_FILE)) :
+                (InputStream) jobProperties.get(Properties.PROP_INPUT_STREAM))) {
 
             if (null != inputStm) {
                 ret = IOUtils.toByteArray(inputStm);
             }
-        } catch (Exception e) {
+        } catch (final Exception e) {
             ClientManager.logExcp(e);
-        } finally {
-            IOUtils.closeQuietly(inputStm);
         }
 
         // check, if length of byte array is larger than specified config source file size
@@ -289,7 +280,8 @@ class ManagedClientJob {
         if (null != jobProperties) {
             // job is valid by default, if job properties exists at all
             // and source file size fits into the given constraints
-            ret = checkJobInputFileSize(jobProperties, resultProperties);
+            ret = checkJobInputFileSize(jobProperties, resultProperties) &&
+                checkSupportedJobInputType(jobProperties, resultProperties);
         } else {
             resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.GENERAL.errorCode()));
         }
@@ -329,6 +321,41 @@ class ManagedClientJob {
         return ret;
     }
 
+    /**
+     * @param jobProperties
+     * @param resultProperties
+     * @return true, if source file size is unlimited or below/equal
+     *  to the given maximum source file size
+     */
+    protected static boolean checkSupportedJobInputType(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+        boolean ret = false;
+
+        if (null != jobProperties) {
+            // check max source file size, if source file is given
+            String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
+
+            if (StringUtils.isEmpty(inputType)) {
+                final String fileName = (String) jobProperties.get(Properties.PROP_INFO_FILENAME);
+
+                if (StringUtils.isNotEmpty(fileName)) {
+                    inputType = FilenameUtils.getExtension(fileName);
+
+                    if (StringUtils.isNotEmpty(inputType)) {
+                        inputType = inputType.trim().toLowerCase();
+                    }
+                }
+            }
+
+            if (StringUtils.isEmpty(inputType)) {
+                inputType = "bin";
+            }
+
+            ret = !setSupportedTypeError(inputType, jobProperties, resultProperties);
+        }
+
+        return ret;
+    }
+
     /**
      * @param sourceSize
      * @param maxSize
@@ -357,6 +384,32 @@ class ManagedClientJob {
         return ret;
     }
 
+    /**
+     * @param sourceSize
+     * @param maxSize
+     * @param resultProperties
+     * @return true, if source size is larger than max size
+     */
+    protected static boolean setSupportedTypeError(String inputType, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+        final Set<String> supportedTypes = ClientManager.getClientConfig().SUPPORTED_TYPES;
+        final boolean ret = (supportedTypes.size() > 0) &&
+            SUPPORTED_TYPE_CHECK_LIST.contains(inputType) &&
+            !supportedTypes.contains(inputType);
+
+        if (ret) {
+            if (null != resultProperties) {
+                resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.UNSUPPORTED.errorCode()));
+            }
+
+            if (ClientManager.isLogError()) {
+                ClientManager.logError("Documentconverter detected unsupported input file extension",
+                    jobProperties, new LogData("inputype", inputType));
+            }
+        }
+
+        return ret;
+    }
+
     /**
      * @param jobProperties
      * @param method
@@ -370,7 +423,7 @@ class ManagedClientJob {
         if (!StringUtils.isEmpty(calledRemoteUrlString)) {
             try {
                 calledRemoteUrl = new URL(calledRemoteUrlString);
-            } catch (MalformedURLException e) {
+            } catch (final MalformedURLException e) {
                 ClientManager.logExcp(e);
             }
         }
@@ -418,63 +471,99 @@ class ManagedClientJob {
         final String remoteMethod = jobProperties.containsKey(Properties.PROP_REMOTE_METHOD) ? (String) jobProperties.get(Properties.PROP_REMOTE_METHOD) : "";
         final String logTitle = (remoteMethod.equals("transformimage")) ?
             ("ImageServer " + (isAsync ? "asynchronous " : "") + "remote transformation") :
-            ("Documentconverter " + (isAsync ? "asynchronous " : "") + "remote conversion");
+                ("Documentconverter " + (isAsync ? "asynchronous " : "") + "remote conversion");
 
-        if ((null != m_remoteUrl) && (null != remoteParams)) {
-            final String callCookie = (String) jobProperties.get(Properties.PROP_CONVERTER_COOKIE);
-            URL remoteUrl = null;
+            if ((null != m_remoteUrl) && (null != remoteParams)) {
+                final String callCookie = (String) jobProperties.get(Properties.PROP_CONVERTER_COOKIE);
+                URL remoteUrl = null;
 
-            if (logTrace) {
-                ClientManager.logTrace(logTitle + " initiated", jobProperties, new LogData("method", remoteMethod));
-            }
+                if (logTrace) {
+                    ClientManager.logTrace(logTitle + " initiated", jobProperties, new LogData("method", remoteMethod));
+                }
 
-            try {
-                remoteUrl = new URL(m_remoteUrl.toString() + "?action=rconvert");
-            } catch (MalformedURLException e) {
-                ClientManager.logExcp(e);
-            }
+                try {
+                    remoteUrl = new URL(m_remoteUrl.toString() + "?action=rconvert");
+                } catch (final MalformedURLException e) {
+                    ClientManager.logExcp(e);
+                }
 
-            if ((null != remoteUrl) && isMultipartRequest) {
-                final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
-                final String inputMimeType = (null != inputType) && (inputType.equals("pdf")) ? "application/pdf" : "application/octet-stream";
-                final Serializable serialObject = getInputBuffer(jobProperties, resultProperties);
+                if ((null != remoteUrl) && isMultipartRequest) {
+                    final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
+                    final String inputMimeType = (null != inputType) && (inputType.equals("pdf")) ? "application/pdf" : "application/octet-stream";
+                    final Serializable serialObject = getInputBuffer(jobProperties, resultProperties);
 
-                if (null != serialObject) {
-                    final TransferObject<Serializable> transferObject = new TransferObject<>(
-                        remoteParams,
-                        serialObject,
-                        "ByteArray.bin",
-                        inputMimeType,
-                        callCookie);
+                    if (null != serialObject) {
+                        final TransferObject<Serializable> transferObject = new TransferObject<>(
+                            remoteParams,
+                            serialObject,
+                            "ByteArray.bin",
+                            inputMimeType,
+                            callCookie);
 
-                    TransferHelper.postFormData(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
+                        TransferHelper.postFormData(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
+
+                            @SuppressWarnings("unchecked")
+                            @Override
+                            public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
+                                try {
+                                    // evaluate result only for synchronous calls with valid result stream
+                                    if (!isAsync && (null != responseInputStream)) {
+                                        try (ObjectInputStream objInputStream = new ObjectInputStream(new BufferedInputStream(responseInputStream))) {
+                                            final Object readObject = objInputStream.readObject();
+
+                                            if ((null != readObject) && (readObject instanceof HashMap<?, ?>)) {
+                                                resultProperties.clear();
+                                                resultProperties.putAll((HashMap<? extends String, ?>) readObject);
+
+                                                if (null != resultCookie) {
+                                                    resultProperties.put(Properties.PROP_RESULT_CONVERTER_COOKIE, resultCookie);
+                                                }
+
+                                                // check for old style property and convert to result error
+                                                final Boolean passwordProtected = (Boolean) resultProperties.get("PasswordProtected");
+
+                                                if ((null != passwordProtected) && passwordProtected.booleanValue()) {
+                                                    resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.PASSWORD.errorCode()));
+                                                }
+                                            }
+                                        } catch (final Exception e) {
+                                            resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.TIMEOUT.errorCode()));
+                                            ClientManager.logExcp(e);
+                                        }
+                                    }
+                                } finally {
+                                    IOUtils.closeQuietly(responseInputStream);
+                                }
+                            }
+                        });
+
+                        final byte[] resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER);
+
+                        if (null != resultBuffer) {
+                            ret = new ByteArrayInputStream(resultBuffer);
+                        }
+                    }
+                } else {
+                    final TransferObject<byte[]> transferObject = new TransferObject<>(remoteParams, callCookie);
+                    final StringBuilder response = new StringBuilder();
+
+                    TransferHelper.postRequest(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
 
-                        @SuppressWarnings("unchecked")
                         @Override
                         public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
                             try {
                                 // evaluate result only for synchronous calls with valid result stream
                                 if (!isAsync && (null != responseInputStream)) {
-                                    try (ObjectInputStream objInputStream = new ObjectInputStream(new BufferedInputStream(responseInputStream))) {
-                                        final Object readObject = objInputStream.readObject();
-
-                                        if ((null != readObject) && (readObject instanceof HashMap<?, ?>)) {
-                                            resultProperties.clear();
-                                            resultProperties.putAll((HashMap<? extends String, ?>) readObject);
-
-                                            if (null != resultCookie) {
-                                                resultProperties.put(Properties.PROP_RESULT_CONVERTER_COOKIE, resultCookie);
-                                            }
-
-                                            // check for old style property and convert to result error
-                                            final Boolean passwordProtected = (Boolean) resultProperties.get("PasswordProtected");
-
-                                            if ((null != passwordProtected) && passwordProtected.booleanValue()) {
-                                                resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.PASSWORD.errorCode()));
-                                            }
+                                    try (BufferedReader inputReader = new BufferedReader(new InputStreamReader(responseInputStream))) {
+                                        for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
+                                            response.append(readLine).append('\n');
                                         }
-                                    } catch (Exception e) {
-                                        resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, CONNECTION_TIMEOUT_ERRORCODE);
+
+                                        if (null != resultCookie) {
+                                            resultProperties.put(Properties.PROP_RESULT_CONVERTER_COOKIE, resultCookie);
+                                        }
+                                    } catch (final Exception e) {
+                                        resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.TIMEOUT.errorCode()));
                                         ClientManager.logExcp(e);
                                     }
                                 }
@@ -484,89 +573,50 @@ class ManagedClientJob {
                         }
                     });
 
-                    final byte[] resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER);
-
-                    if (null != resultBuffer) {
-                        ret = new ByteArrayInputStream(resultBuffer);
-                    }
-                }
-            } else {
-                final TransferObject<byte[]> transferObject = new TransferObject<>(remoteParams, callCookie);
-                final StringBuilder response = new StringBuilder();
-
-                TransferHelper.postRequest(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
-
-                    @Override
-                    public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
+                    // parse JSON response only on case of synchronous jobs,
+                    // since we won't get a valid answer for async requests
+                    if (!isAsync) {
                         try {
-                            // evaluate result only for synchronous calls with valid result stream
-                            if (!isAsync && (null != responseInputStream)) {
-                                try (BufferedReader inputReader = new BufferedReader(new InputStreamReader(responseInputStream))) {
-                                    for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
-                                        response.append(readLine).append('\n');
-                                    }
-
-                                    if (null != resultCookie) {
-                                        resultProperties.put(Properties.PROP_RESULT_CONVERTER_COOKIE, resultCookie);
-                                    }
-                                } catch (Exception e) {
-                                    resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, CONNECTION_TIMEOUT_ERRORCODE);
-                                    ClientManager.logExcp(e);
-                                }
-                            }
-                        } finally {
-                            IOUtils.closeQuietly(responseInputStream);
+                            ret = parseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
+                        } catch (final JSONException e) {
+                            ClientManager.logExcp(e);
                         }
                     }
-                });
-
-                // parse JSON response only on case of synchronous jobs,
-                // since we won't get a valid answer for async requests
-                if (!isAsync) {
-                    try {
-                        ret = parseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
-                    } catch (JSONException e) {
-                        ClientManager.logExcp(e);
-                    }
                 }
             }
-        }
 
-        if (isAsync) {
-            if (logTrace) {
-                ClientManager.logTrace(logTitle + " implicitly succeeded", jobProperties);
-            }
-        } else if (!resultProperties.containsKey(Properties.PROP_RESULT_ERROR_CODE) || (0 == ((Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)).intValue())) {
-            if (logTrace) {
-                ClientManager.logTrace(logTitle + " succeeded", jobProperties);
-            }
-        } else if (ClientManager.isLogWarn()) {
-            // don't log warnings for cacheOnly jobs /
-            // don't log warnings for async jobs /
-            // don't log warnings for remote cachehash jobs
-            // ------------------------------------------------------
-            // all above mentioned types of jobs may return without a
-            // valid or with an error result. This should not be logged
-            // as an error/warning at all here, since there'll either be a
-            // fallback conversion or the caller is not interested in the
-            // the current result of these 'try and ignore' conversions
-            if (!isCacheOnly && !isAsync && StringUtils.isEmpty(remoteCacheHash)) {
-                final StringBuilder errorMessageBuilder = new StringBuilder("Documentconverter received a remote conversion ");
-                Integer resultErrorCode = (Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE);
-
-                if (null == resultErrorCode) {
-                    resultErrorCode = new Integer(JobError.GENERAL.errorCode());
+            if (isAsync) {
+                if (logTrace) {
+                    ClientManager.logTrace(logTitle + " implicitly succeeded", jobProperties);
                 }
+            } else if (JobError.NONE == JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE))) {
+                if (logTrace) {
+                    ClientManager.logTrace(logTitle + " succeeded", jobProperties);
+                }
+            } else if (ClientManager.isLogWarn()) {
+                // don't log warnings for cacheOnly jobs /
+                // don't log warnings for async jobs /
+                // don't log warnings for remote cachehash jobs
+                // ------------------------------------------------------
+                // all above mentioned types of jobs may return without a
+                // valid or with an error result. This should not be logged
+                // as an error/warning at all here, since there'll either be a
+                // fallback conversion or the caller is not interested in the
+                // the current result of these 'try and ignore' conversions
+                if (!isCacheOnly && !isAsync && StringUtils.isEmpty(remoteCacheHash)) {
+                    final StringBuilder errorMessageBuilder = new StringBuilder("Documentconverter received a remote conversion ");
+                    final JobError jobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
 
-                ClientManager.logWarn(errorMessageBuilder.append(
-                    resultErrorCode.equals(CONNECTION_TIMEOUT_ERRORCODE) ? "timeout error" :
-                        (JobError.fromErrorCode(resultErrorCode.intValue()) == JobError.NO_CONTENT) ? "no content error" :
-                            (JobError.fromErrorCode(resultErrorCode.intValue()) == JobError.PASSWORD) ? "password error" :
-                                (JobError.fromErrorCode(resultErrorCode.intValue()) == JobError.MAX_SOURCESIZE) ? "max source size error" : "general error").toString());
+                    ClientManager.logWarn(errorMessageBuilder.append(
+                        (JobError.TIMEOUT == jobError) ? "timeout error" :
+                            (JobError.NO_CONTENT == jobError) ? "no content error" :
+                                (JobError.PASSWORD == jobError) ? "password error" :
+                                    (JobError.MAX_SOURCESIZE == jobError) ? "max source size error" :
+                                        "general error").toString());
+                }
             }
-        }
 
-        return ret;
+            return ret;
     }
 
     /**
@@ -670,7 +720,7 @@ class ManagedClientJob {
 
                 try {
                     paramBuilder.append("&infofilename=").append(URLEncoder.encode(infoFileName, "UTF-8"));
-                } catch (UnsupportedEncodingException e) {
+                } catch (final UnsupportedEncodingException e) {
                     ClientManager.logExcp(e);
                 }
             }
@@ -710,16 +760,6 @@ class ManagedClientJob {
                 paramBuilder.append("&queryavailability=").append(((Boolean) curParam).toString());
             }
 
-            // ImageFormat
-            if (null != (curParam = jobProperties.get(Properties.PROP_IMAGE_FORMAT))) {
-                paramBuilder.append("&imageformat=").append((String) curParam);
-            }
-
-            // ImageTransformations
-            if (null != (curParam = jobProperties.get(Properties.PROP_IMAGE_TRANSFORMATIONS))) {
-                paramBuilder.append("&imagetransformations=").append(((ImageServerTransformations) curParam).toString());
-            }
-
             // ImageResolution
             if (null != (curParam = jobProperties.get(Properties.PROP_IMAGE_RESOLUTION))) {
                 paramBuilder.append("&imageresolution=").append(((Integer) curParam).toString());
@@ -730,17 +770,12 @@ class ManagedClientJob {
                 paramBuilder.append("&imagescaletype=").append((String) curParam);
             }
 
-            // ShrinkOnly
-            if (null != (curParam = jobProperties.get(Properties.PROP_IMAGE_SHRINK_ONLY))) {
-                paramBuilder.append("&imageshrinkonly=").append(((Boolean) curParam).toString());
-            }
-
             // RemoteUrl
             paramBuilder.append("&remoteurl=").append(m_remoteUrl.toString());
 
             // add additional params, if available
             if (null != additionalParams) {
-                for (String curParamStr : additionalParams) {
+                for (final String curParamStr : additionalParams) {
                     if ((null != curParamStr) && (curParamStr.indexOf('=') > 0)) {
                         paramBuilder.append('&').append(curParamStr);
                     }
@@ -761,7 +796,7 @@ class ManagedClientJob {
                         if (null != base64String) {
                             paramBuilder.append("&url=data:").append(inputMimeType).append(";base64,").append(base64String);
                         }
-                    } catch (Exception e) {
+                    } catch (final Exception e) {
                         ClientManager.logExcp(e);
                         paramBuilder = null;
                     }
@@ -831,16 +866,8 @@ class ManagedClientJob {
                     resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.MAX_SOURCESIZE.errorCode()));
                 }
 
-                if (keys.contains("imageformat")) {
-                    resultProperties.put(Properties.PROP_RESULT_IMAGE_FORMAT, jsonObject.getString("imageformat"));
-                }
-
-                if (keys.contains("pixelwidth")) {
-                    resultProperties.put(Properties.PROP_RESULT_IMAGE_WIDTH, Integer.valueOf(jsonObject.getInt("pixelwidth")));
-                }
-
-                if (keys.contains("pixelheight")) {
-                    resultProperties.put(Properties.PROP_RESULT_IMAGE_HEIGHT, Integer.valueOf(jsonObject.getInt("pixelheight")));
+                if (keys.contains("unsupported") && jsonObject.getBoolean("unsupported")) {
+                    resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.UNSUPPORTED.errorCode()));
                 }
 
                 if (keys.contains("result")) {
@@ -873,7 +900,7 @@ class ManagedClientJob {
                     }
                 }
             }
-        } catch (JSONException e) {
+        } catch (final JSONException e) {
             ClientManager.logExcp(e);
         }
 
@@ -910,7 +937,67 @@ class ManagedClientJob {
 
     protected static final String RCALL_ENDPAGECONVERSION = "endpageconversion";
 
-    protected static final Integer CONNECTION_TIMEOUT_ERRORCODE = Integer.valueOf(999);
-
     protected static Map<String, String> m_converterCookieMap = new ConcurrentHashMap<>();
+
+    protected static final Set<String> SUPPORTED_TYPE_CHECK_LIST = new HashSet<>();
+
+    {
+        // List of all supported types
+        // csv,doc,docm,docx,docxm,dot,dotm,dotx,dotxm,fodp,fods,fodt,html,odg,odgm,odp,odpm,ods,odsm,odt,odtm,otg,otgm,otm,ots,otsm,odtm,otgm,otp,otpm,ott,ottm,pot,potm,potx,pps,ppt,pptm,pptx,rtf,txt,xlm,xls,xlsm,xlst,xlstm,xlt,xltm,xlsb,xlsx,xlsxm,xltx,xltxm
+
+        // static initialization
+        SUPPORTED_TYPE_CHECK_LIST.add("csv");
+        SUPPORTED_TYPE_CHECK_LIST.add("doc");
+        SUPPORTED_TYPE_CHECK_LIST.add("docm");
+        SUPPORTED_TYPE_CHECK_LIST.add("docx");
+        SUPPORTED_TYPE_CHECK_LIST.add("docxm");
+        SUPPORTED_TYPE_CHECK_LIST.add("dot");
+        SUPPORTED_TYPE_CHECK_LIST.add("dotm");
+        SUPPORTED_TYPE_CHECK_LIST.add("dotx");
+        SUPPORTED_TYPE_CHECK_LIST.add("dotxm");
+        SUPPORTED_TYPE_CHECK_LIST.add("fodp");
+        SUPPORTED_TYPE_CHECK_LIST.add("fods");
+        SUPPORTED_TYPE_CHECK_LIST.add("fodt");
+        SUPPORTED_TYPE_CHECK_LIST.add("html");
+        SUPPORTED_TYPE_CHECK_LIST.add("odg");
+        SUPPORTED_TYPE_CHECK_LIST.add("odgm");
+        SUPPORTED_TYPE_CHECK_LIST.add("odp");
+        SUPPORTED_TYPE_CHECK_LIST.add("odpm");
+        SUPPORTED_TYPE_CHECK_LIST.add("ods");
+        SUPPORTED_TYPE_CHECK_LIST.add("odsm");
+        SUPPORTED_TYPE_CHECK_LIST.add("odt");
+        SUPPORTED_TYPE_CHECK_LIST.add("odtm");
+        SUPPORTED_TYPE_CHECK_LIST.add("otg");
+        SUPPORTED_TYPE_CHECK_LIST.add("otgm");
+        SUPPORTED_TYPE_CHECK_LIST.add("otm");
+        SUPPORTED_TYPE_CHECK_LIST.add("ots");
+        SUPPORTED_TYPE_CHECK_LIST.add("otsm");
+        SUPPORTED_TYPE_CHECK_LIST.add("otp");
+        SUPPORTED_TYPE_CHECK_LIST.add("otpm");
+        SUPPORTED_TYPE_CHECK_LIST.add("ott");
+        SUPPORTED_TYPE_CHECK_LIST.add("ottm");
+        SUPPORTED_TYPE_CHECK_LIST.add("pot");
+        SUPPORTED_TYPE_CHECK_LIST.add("potm");
+        SUPPORTED_TYPE_CHECK_LIST.add("potx");
+        SUPPORTED_TYPE_CHECK_LIST.add("potxm");
+        SUPPORTED_TYPE_CHECK_LIST.add("pps");
+        SUPPORTED_TYPE_CHECK_LIST.add("ppt");
+        SUPPORTED_TYPE_CHECK_LIST.add("pptm");
+        SUPPORTED_TYPE_CHECK_LIST.add("pptx");
+        SUPPORTED_TYPE_CHECK_LIST.add("pptxm");
+        SUPPORTED_TYPE_CHECK_LIST.add("rtf");
+        SUPPORTED_TYPE_CHECK_LIST.add("txt");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlm");
+        SUPPORTED_TYPE_CHECK_LIST.add("xls");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlsb");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlsm");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlst");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlstm");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlt");
+        SUPPORTED_TYPE_CHECK_LIST.add("xltm");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlsx");
+        SUPPORTED_TYPE_CHECK_LIST.add("xlsxm");
+        SUPPORTED_TYPE_CHECK_LIST.add("xltx");
+        SUPPORTED_TYPE_CHECK_LIST.add("xltxm");
+    }
 }
