@@ -59,9 +59,6 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
-import org.apache.commons.io.IOUtils;
-
 import com.openexchange.documentconverter.LogData;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.ServerType;
@@ -93,10 +90,11 @@ class RemoteValidator {
         public Integer call() throws Exception {
             // check remote connection API; may be checked repeatedly, if a valid remote URL is set
             HttpURLConnection connection = null;
-            BufferedReader inputReader = null;
             int remoteApiVersion = 0;
 
             try {
+                final long validateStartTime = System.currentTimeMillis();
+
                 connection = (HttpURLConnection) m_remoteUrl.openConnection();
 
                 if (null != connection) {
@@ -104,35 +102,33 @@ class RemoteValidator {
 
                     connection.setRequestMethod("GET");
                     connection.setUseCaches(false);
+                    connection.setConnectTimeout(20000);
+                    connection.setReadTimeout(20000);
                     connection.connect();
 
                     // read default response and check for 'documentconverter' content
-                    inputReader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
+                    try (final BufferedReader inputReader = new BufferedReader(new InputStreamReader(connection.getInputStream()))) {
+                        for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
+                            readLine = readLine.toLowerCase();
 
-                    for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
-                        readLine = readLine.toLowerCase();
+                            if (readLine.contains("open") && readLine.contains("xchange") && (readLine.contains(m_engineTypeName))) {
+                                if (remoteApiVersion <= 0) {
+                                    remoteApiVersion = 1;
+                                }
+                            } else if (readLine.contains("api:")) {
+                                final Matcher matcher = apiVersionPattern.matcher(readLine);
 
-                        if (readLine.contains("open") && readLine.contains("xchange") && (readLine.contains(m_engineTypeName))) {
-                            if (remoteApiVersion <= 0) {
-                                remoteApiVersion = 1;
-                            }
-                        } else if (readLine.contains("api:")) {
-                            final Matcher matcher = apiVersionPattern.matcher(readLine);
-
-                            if (matcher.find()) {
-                                remoteApiVersion = Integer.valueOf(matcher.group(1)).intValue();
+                                if (matcher.find()) {
+                                    remoteApiVersion = Integer.valueOf(matcher.group(1)).intValue();
+                                }
                             }
                         }
                     }
-
-                    inputReader.close();
                 }
-            } catch (Exception e) {
+            } catch (@SuppressWarnings("unused") Exception e) {
+                // #52867: no exception logging intended here
                 remoteApiVersion = -1;
-                ClientManager.logExcp(e);
             } finally {
-                IOUtils.closeQuietly(inputReader);
-
                 // disconnect and try again, if no valid answer has been received so far
                 if (remoteApiVersion < 1) {
                     if (null != connection) {
@@ -140,6 +136,10 @@ class RemoteValidator {
                     }
 
                     if (m_remoteAPIVersion.get() > 0) {
+                        if (ClientManager.isLogTrace()) {
+                            ClientManager.logTrace("Documentconverter setting remote connection lost after wait time of " + System.currentTimeMillis() + "ms");
+                        }
+
                         setConnectionLost();
                     } else {
                         synchronized (self) {
