@@ -46,15 +46,12 @@
  *
  */
 
+
 package com.openexchange.documentconverter.client.json;
 
 import java.io.InputStream;
-import java.util.Collections;
 import java.util.EnumSet;
-import java.util.LinkedHashMap;
-import java.util.Map;
 import java.util.concurrent.atomic.AtomicLong;
-import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
@@ -80,14 +77,12 @@ import com.openexchange.file.storage.composition.crypto.CryptographyMode;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.groupware.attach.Attachments;
-import com.openexchange.guard.api.GuardApi;
-import com.openexchange.guard.api.GuardApis;
-import com.openexchange.guard.api.Header;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
+
 /**
  * {@link DocumentConverterAction}
  *
@@ -101,7 +96,7 @@ public class DocumentConverterAction implements AJAXActionService {
     // The parameter list is used for the fast detection of ManagedFiles, based on
     // the set of all given attributes to create a unique identifier. The ManagedFile itself
     // is created for the speedup of chunked requests, using the same source again and again
-    static final private String[] idParamArray = { "uid", "id", "folder_id", "version", "source", "attached", "module", "cryptoAuth" };
+    final static private String[] idParamArray = { "uid", "id", "folder_id", "version", "revtag", "source", "attached", "module", "cryptoAuth", "attachmentId" };
 
     /**
      * Initializes a new {@link DocumentConverterAction}.
@@ -146,7 +141,7 @@ public class DocumentConverterAction implements AJAXActionService {
         }
     }
 
-    /**
+    /**@param documentId
      * @param request
      * @param session
      * @param jobError
@@ -173,10 +168,8 @@ public class DocumentConverterAction implements AJAXActionService {
                 final String folderId = request.getParameter("folder_id");
                 final String version = request.getParameter("version");
                 final String cryptoAuth = request.getParameter("cryptoAuth");
-                final String guardUrl = request.getParameter("guardUrl");
                 final boolean mailCheck = ((attached != null) && (folderId != null) && (attached.length() > 0));
                 final boolean taskCheck = mailCheck && (module != null);
-                final boolean oldStyleGuardCheck = (null != guardUrl) && (guardUrl.length() > 10);
                 @SuppressWarnings("resource") MailServletInterface mailServletInterface = null; // closing done in finally block
                 @SuppressWarnings("resource") InputStream documentStm = null; // closing done in finally block
 
@@ -193,9 +186,7 @@ public class DocumentConverterAction implements AJAXActionService {
                                 authentication = encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest());
                             }
 
-                            // not yet available in 7.8.3, use default instance
-                            // mailServletInterface = MailServletInterface.getInstanceWithDecryptionSupport(session,  authentication);
-                            mailServletInterface = MailServletInterface.getInstance(session);
+                            mailServletInterface = MailServletInterface.getInstanceWithDecryptionSupport(session,  authentication);
                         } else {
                             mailServletInterface = MailServletInterface.getInstance(session);
                         }
@@ -209,6 +200,7 @@ public class DocumentConverterAction implements AJAXActionService {
                         }
                     } else if (taskCheck && ("tasks".equals(source) || "calendar".equals(source) || "contacts".equals(source))) {
                         // other attachment from tasks, calendar or contact
+
                         documentStm = Attachments.getInstance().getAttachedFile(
                             session,
                             Integer.parseInt(folderId),
@@ -218,24 +210,6 @@ public class DocumentConverterAction implements AJAXActionService {
                             session.getContext(),
                             session.getUser(),
                             session.getUserConfiguration());
-                    } else if ((null != source) && (source.equals("guard")) && oldStyleGuardCheck) {
-                        // Old style Guard encryption may still occur. This is used for email attachments,
-                        // The guardUrl paameter provides information to retrieve data from email mime body
-                        final GuardApi guardApi = m_services.getOptionalService(GuardApi.class);
-
-                        if (null != guardApi) {
-                            final HttpServletRequest httpServletRequest = request.optHttpServletRequest();
-
-                            if (null != httpServletRequest) {
-                                final String userAgent = httpServletRequest.getHeader("User-Agent");
-
-                                documentStm = guardApi.requestSessionSensitiveResource(
-                                    parseQueryStringFromUrl(guardUrl),
-                                    session,
-                                    GuardApis.extractCookiesFrom(httpServletRequest, session),
-                                    (null == userAgent) ? Collections.<Header> emptyList() : Collections.singletonList(new Header("User-Agent", userAgent)));
-                            }
-                        }
                     } else {
                         // use FileStore as default data source
                         final IDBasedFileAccessFactory fileFactory = m_services.getService(IDBasedFileAccessFactory.class);
@@ -252,7 +226,8 @@ public class DocumentConverterAction implements AJAXActionService {
 
                                     fileAccess = encryptionAwareFileAccessFactory.createAccess(fileAccess, cryptMode, session,
                                         encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest()));
-                                } else {
+                                }
+                                else {
                                     // file is encrypted, but we can't decrypt...
                                     fileAccess = null;
                                 }
@@ -346,6 +321,11 @@ public class DocumentConverterAction implements AJAXActionService {
                         break;
                     }
 
+                    case UNSUPPORTED: {
+                        errorCause = "unsupportedType";
+                        break;
+                    }
+
                     case GENERAL:
                     default: {
                         errorCause = "filterError";
@@ -367,58 +347,11 @@ public class DocumentConverterAction implements AJAXActionService {
         return ret;
     }
 
-    /**
-    * Parses a query string from given URL.
-    *
-    * @param uri The URI string to be parsed
-    * @return The parsed parameters or <code>null</code>
-    */
-    Map<String, String> parseQueryStringFromUrl(String uri) {
-        if (StringUtils.isEmpty(uri)) {
-            return null;
-        }
-        try {
-            final String query = new java.net.URI(uri).getQuery();
-            if (null != query) {
-                return parseQueryString(query);
-            }
-        } catch (final Exception e) {
-            logException(e);
-        }
-        return null;
-    }
-
     String getDefaultEncoding() {
         final ConfigurationService configurationService = m_services.getOptionalService(ConfigurationService.class);
         return null == configurationService ? "UTF-8" : configurationService.getProperty("DefaultEncoding", "UTF-8").trim();
     }
 
-    private static final java.util.regex.Pattern PATTERN_SPLIT = java.util.regex.Pattern.compile("&");
-
-    /**
-     * Parses given query string.
-     *
-     * @param queryStr The query string to be parsed
-     * @return The parsed parameters
-     */
-    static Map<String, String> parseQueryString(String queryStr) {
-        final String[] pairs = PATTERN_SPLIT.split(queryStr, 0);
-        final Map<String, String> map = new LinkedHashMap<>(4);
-        for (String pair : pairs) {
-            pair = pair.trim();
-            if (pair.length() > 0) {
-                // Look-up character '='
-                final int pos = pair.indexOf('=');
-                if (pos >= 0) {
-                    map.put(pair.substring(0, pos), pair.substring(pos + 1));
-                } else {
-                    map.put(pair, "");
-                }
-            }
-        }
-        return map;
-    }
-
     /**
      * @param request
      * @param fileHolder
@@ -478,3 +411,4 @@ public class DocumentConverterAction implements AJAXActionService {
 
     protected long m_maxSourceFileSizeMB = 32;
 }
+
