@@ -49,6 +49,7 @@
 package com.openexchange.documentconverter.client.osgi;
 
 import java.net.URL;
+import java.util.List;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -68,7 +69,6 @@ import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.guard.api.GuardApi;
-import com.openexchange.imagetransformation.ImageServerTransformationService;
 import com.openexchange.imagetransformation.ImageTransformationService;
 import com.openexchange.preview.InternalPreviewService;
 
@@ -133,7 +133,6 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
                     if (null != m_clientManager) {
                         log.info("Registering DocumentConverter services");
                         registerService(IDocumentConverter.class, m_clientManager, null);
-                        registerService(ImageServerTransformationService.class, m_clientManager, null);
                     } else {
                         log.error("Could not register DocumentConverter services");
                     }
@@ -145,13 +144,13 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
                     log.info("Registering DocumentConverterPreviewService");
                     registerService(InternalPreviewService.class, new DocumentConverterPreviewService(this));
                 }
-            } catch (@SuppressWarnings("unused") Exception e) {
+            } catch (@SuppressWarnings("unused") final Exception e) {
                 if (log.isErrorEnabled()) {
                     log.error("starting bundle failed: " + m_serviceName);
                     log.error("Documentconverter manager could not be initialized");
                 }
             }
-        } catch (Throwable e) {
+        } catch (final Throwable e) {
             e.printStackTrace();
         }
 
@@ -173,7 +172,7 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
         if (!StringUtils.isEmpty(curStringEntry = configService.getProperty("com.openexchange.documentconverter.client.remoteDocumentConverterUrl", emptyString))) {
             try {
                 clientConfig.REMOTEURL_DOCUMENTCONVERTER = curStringEntry.startsWith("http") ? new URL(curStringEntry) : null;
-            } catch (@SuppressWarnings("unused") Exception e) {
+            } catch (@SuppressWarnings("unused") final Exception e) {
                 if (log.isErrorEnabled()) {
                     log.error("com.openexchange.documentconverter.client.remoteDocumentConverterUrl is not a valid http URL: " + curStringEntry + " => Remote document conversion disabled!");
                 }
@@ -189,21 +188,6 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
             clientConfig.MAX_DOCUMENT_SOURCEFILESIZE = (curIntEntry > 0) ? (curIntEntry * 1024 * 1024) : curIntEntry;
         }
 
-        // REMOTEURL_IMAGESERVER
-        if (!StringUtils.isEmpty(curStringEntry = configService.getProperty("com.openexchange.documentconverter.client.remoteImageServerUrl", emptyString))) {
-            try {
-                clientConfig.REMOTEURL_IMAGESERVER = curStringEntry.startsWith("http") ? new URL(curStringEntry) : null;
-            } catch (@SuppressWarnings("unused") Exception e) {
-                if (log.isErrorEnabled()) {
-                    log.error("com.openexchange.documentconverter.client.remoteImageServerUrl is not a valid http URL: " + curStringEntry + " => Remote image transformation disabled!");
-                }
-
-                clientConfig.REMOTEURL_IMAGESERVER = null;
-            }
-        } else if (log.isErrorEnabled()) {
-            log.error("com.openexchange.documentconverter.client.remoteImageServerUrl is not set at all => ImageServer functionality will not be available!");
-        }
-
         // MAX_IMAGE_SOURCEFILESIZE_MB
         if ((curIntEntry = configService.getIntProperty("com.openexchange.documentconverter.client.maxImageSourceFileSizeMB", emptyInt)) != emptyInt) {
             clientConfig.MAX_IMAGE_SOURCEFILESIZE = (curIntEntry > 0) ? (curIntEntry * 1024 * 1024) : curIntEntry;
@@ -212,6 +196,15 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
         // PREVIEW_ENABLE_CACHE_LOOKUP
         clientConfig.PREVIEW_ENABLE_CACHE_LOOKUP = configService.getBoolProperty("com.openexchange.documentconverter.enableCacheLookup", false);
 
+        // SUPPORTED_TYPES
+        final List<String> configList = configService.getProperty("com.openexchange.documentconverter.client.supportedTypes", "", ",");
+
+        if ((null != configList) && configList.size() > 0) {
+            for (final String curEntry : configList) {
+                clientConfig.SUPPORTED_TYPES.add(curEntry.toLowerCase());
+            }
+        }
+
         // - Internally used config items ----------------------------------
 
         // ENGINE_LOGFILE
